import {
  select,
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';

const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');

// putting % sign 
const numberFormat = number =>
  	(Math.abs(Number(number))) + " %" ;


const render = data => {
  //selecting the column of data that needed to be displayed in piechart
  const pieData = pie().sort(null).value(d=>d.smokingRate)(data);
  const colors = scaleOrdinal(schemeCategory10);
	//defining the size and feature of pie chart
  const segments = arc()
  	.innerRadius(0)
  	.outerRadius(200)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.smokingRate))
  	.on("mouseover", d => console.log(d.data.smokingRate));
  //piechart is created 
  const legends = svg.append("g")
  	.attr("transform", "translate(500,60)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  // list of each country as labels and its styles

  legend.append("rect").attr("width",22).attr("height",25)
  	.attr("fill", d => colors(d.data.smokingRate));
  legend.append("text")
  	.attr("x", 28)
  	.attr("y", 18)
  	.attr("class","legend_text")
  	.text(d => d.data.state);
  legend.append("text")
  	.attr("x", 260)
  	.attr("y", 20)
  	.attr("class","legend_value")
  	.text(d=>numberFormat(d.data.smokingRate));
}

// url of my data giest

const csvUrl =
 'https://gist.githubusercontent.com/Rinoj-Gautam/d67d94a062f9d0ec673a64e3197c3404/raw/f049ea690139811dbeff3d09514b47594fce26a1/Smokingrate.csv';


//Load the data and display the smokingRate in US States
csv(csvUrl).then(csvData => {
    csvData.sort((data1, data2) => data2.smokingRate-data1.smokingRate);
  //selecting the highest 10 Smoking Rate to display  
  if (csvData) {
      render(csvData.slice(0, 10));
    }
});